﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class CollectObjects : MonoBehaviour
{
    [SerializeField]
    private Transform parentItem;
    [SerializeField]
    private Transform parentItemIdle;
    [SerializeField]
    private bool canDestroy;
    [SerializeField, Header("===> In Game")]
    private GameObject currItem;

    private Rigidbody2D rb;

    public GameObject GetCurrentItem { get => currItem; }

    private bool hasItem = false;

    private void Awake()
    {
        rb = GetComponent<Rigidbody2D>();
    }

    private void OnTriggerEnter2D(Collider2D other)
    {
        Debug.Log("Collect Object");

        if (canDestroy)
        {
            var rb = other.GetComponent<Rigidbody2D>();
            rb.transform.SetParent(parentItem);
            rb.isKinematic = true;

            currItem = rb.gameObject;
            currItem.transform.position = parentItem.position;

            Item i = rb.GetComponent<Item>();
			GameManager.Instance.OnItemSaved(i.ItemPoint);
			if(i.IsCookie) SoundManager.Instance.PlayYingCookiePickUp();
			else SoundManager.Instance.PlayYingPickUp();

            DestroyItem(other.gameObject);
        }
        else
        {
            if (!hasItem)
            {
                hasItem = true;
                if (currItem)
                    return;

				SoundManager.Instance.PlayYangPickUp();

                var rb = other.GetComponent<Rigidbody2D>();
                var spriteRenderer = other.GetComponent<Item>().anim.GetComponent<SpriteRenderer>();
                spriteRenderer.sortingOrder = 2;

                rb.transform.SetParent(parentItem);
                rb.isKinematic = true;

                rb.GetComponent<Item>().RemoveSpawn();

                currItem = rb.gameObject;
                currItem.transform.position = parentItem.position;
            }
        }
    }

    void DestroyItem(GameObject _g)
    {
        Destroy(_g, 0.5f);
    }

    private void Update()
    {
        if(currItem)
        {
            if(rb != null && rb.velocity.magnitude == 0) 
                currItem.transform.position = parentItemIdle.position;
            else
                currItem.transform.position = parentItem.position;
        }
    }

    public void ReleaseCurrent()
	{
		currItem = null;
	}

    private void OnTriggerExit2D(Collider2D collision)
    {
        hasItem = false;
    }
}
