﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class CollectorMove : MonoBehaviour, Dasher {
    [SerializeField]
    private InputBase inputPlayer;
    [SerializeField, Header("-- VARIABLES")]
    private float speed = 450f;
    [SerializeField]
    private float gestureTime = 0.3f;
    [SerializeField]
    private float dashingTime = 0.2f;

    private Rigidbody2D rb;
    private float inputX;
    private DashDetector dashDetector;
    private float startDashing = 0f;
    private float speedMultiplier = 1f;
    private bool dashing = false;
    private float dashDirection = 0;

    public bool IsDashing { get => dashing; }
    public bool CanStartPlayer { get; set; }
    public Rigidbody2D Rb { get => rb;}

    private void Awake()
    {
        rb = GetComponent<Rigidbody2D>();
        dashDetector = new DashDetector(this, gestureTime);
    }

    private void Update()
    {
        if(CanStartPlayer)
        {
            inputX = inputPlayer.GetXInput();
            if (!dashing)
            {
                if (inputPlayer.GetJumpInput())
                {
                    Dash(inputX);
                }
            }
        }
        else
        {
            rb.velocity = Vector2.zero;
        }
    }

    public void Dash(float direction)
    {
        dashing = true;
        if (direction > 0)
        {
            dashDirection = 1;
        }
        else
        {
            dashDirection = -1;
        }
        startDashing = Time.time;
        speedMultiplier = 3;
        Debug.Log("Dash!" + startDashing);
		SoundManager.Instance.PlayDash();
    }

    private void FixedUpdate()
    {
        if (CanStartPlayer)
        {
            //dashDetector.insertCurrentDirection(inputX);
            if (dashing && Time.time - startDashing > dashingTime)
            {
                dashing = false;
                speedMultiplier = 1;
                Debug.Log("End dashing " + Time.time);
                rb.velocity = new Vector2((inputX * speed * speedMultiplier) * Time.fixedDeltaTime, rb.velocity.y);
            }
            else if (dashing)
            {
                rb.velocity = new Vector2((dashDirection * speed * speedMultiplier) * Time.fixedDeltaTime, rb.velocity.y);
            }
            else if (inputX > 0.01f || inputX < -0.01f)
            {
                rb.velocity = new Vector2((inputX * speed * speedMultiplier) * Time.fixedDeltaTime, rb.velocity.y);
            }
        }
    }
}
