﻿using System;
using UnityEngine;

public class GameManager : MonoBehaviour
{
	[SerializeField] private int _maxNoiseAllowed;

	public event Action<float> OnNoiseChanged;
	public event Action<int, GameState.Round> OnPointsChanged;
	public event Action<int, GameState.Round> OnGameEnd;

	public static GameManager Instance;

	private int _noiseAccumulated;
	private int _pointsAccumulated;

    [SerializeField]
    private GameState.Round state;

	private void Awake()
	{
		Instance = this;
        state = GameState.Round.first;
    }

	private void OnDestroy()
	{
		OnNoiseChanged = null;
		OnPointsChanged = null;
		OnGameEnd = null;
		Instance = null;
	}

	private void Start()
	{
		OnNoiseChanged?.Invoke(0);
		OnPointsChanged?.Invoke(_pointsAccumulated, state);

        RestartGame.Instance.StartGame();
	}

	public void OnItemBroken(int noisePoints)
	{
		_noiseAccumulated += noisePoints;
		OnNoiseChanged?.Invoke((float)_noiseAccumulated / _maxNoiseAllowed);
        if (_noiseAccumulated >= _maxNoiseAllowed)
        {
            CheckGame(_pointsAccumulated);
        }

	}

	public void OnItemSaved(int playerPoints)
	{
		_pointsAccumulated += playerPoints;
		OnPointsChanged?.Invoke(_pointsAccumulated,state);
	}

    void CheckGame(int pointsEnd)
    {
        _noiseAccumulated = 0;
        OnNoiseChanged?.Invoke((float)_noiseAccumulated / _maxNoiseAllowed);

        switch (state)
        {
            case GameState.Round.first:
                state = GameState.Round.second;
                OnGameEnd?.Invoke(_pointsAccumulated, state);
                break;
            case GameState.Round.second:
                state = GameState.Round.end;
                OnGameEnd?.Invoke(_pointsAccumulated, state);
                break;
            case GameState.Round.end:
                break;
        }
    }
}
