﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Item : MonoBehaviour
{
    [SerializeField]
    private Rigidbody2D rb;
    [SerializeField]
    private CircleCollider2D collider2;
    [SerializeField]
    private SpawnPoint spawnPoint;
    [SerializeField]
    public Animator anim;

    [SerializeField, Header("VARIABLES")]
    private float timeDestroy = 1;
    [SerializeField]
    private int itemPoint = 1;
    [SerializeField]
    private int itemSoundAmount = 1; 
    [SerializeField]
    private string broke;

	[SerializeField] private AudioClip _breakEffect;

	public bool IsCookie;
    public float acceleration = 0f;

    public float sizeX = 1f;
    public float sizeY = 1f;

    public int ItemSoundAmount { get => itemSoundAmount; }
    public int ItemPoint { get => itemPoint; }

    private void Awake()
    {
        rb = GetComponent<Rigidbody2D>();
        collider2 = GetComponent<CircleCollider2D>();
    }

    void Update()
    {
        if (acceleration > 0f && !transform.parent)
        {
            transform.Rotate(Vector3.forward * acceleration);
        }
        else
        {
            transform.rotation = Quaternion.identity;
        }
    }

    public void SetSpawn(SpawnPoint _point)
    {
        spawnPoint = _point;
    }

    public void RemoveSpawn()
    {
        spawnPoint.RemoveItem();
    }

    private void OnCollisionEnter2D(Collision2D other)
    {
        acceleration = 0f;
        var spriteRenderer = anim.GetComponent<SpriteRenderer>();
        spriteRenderer.sortingOrder = 3;
        if (other.gameObject.tag == "Ground")
        {
			SoundManager.Instance.PlayEffect(_breakEffect);
            GameManager.Instance.OnItemBroken(itemSoundAmount);
            rb.simulated = false;
            collider2.enabled = false;
            anim.SetBool(broke, true);
            Destroy(this.gameObject, timeDestroy);
        }
    }

    public void Removeme()
    {
        Destroy(this.gameObject, 0);
    }
}
