﻿using UnityEngine;
using DG.Tweening;
using UnityEngine.UI;

public class Aimer : MonoBehaviour
{
    // Change to externally set
    private bool HasObject => _collectObjects.GetCurrentItem != null;

    [SerializeField] private bool _isFacingRight;

    [SerializeField] private ShooterController _shooterController;
    [SerializeField] private CollectObjects _collectObjects;

    [Header("Config")]
    [SerializeField]
    private float _aimSpeed;
    [SerializeField] [Range(10, 90)] private float _maxAngle;
    [SerializeField] private float _minForce;
    [SerializeField] private float _maxForce;
    [SerializeField] private float _maxForceTime;

    [Header("Visual")]
    [SerializeField] private Transform _aimTransform;
	[SerializeField] private Image _aimSlider;
	[SerializeField] private Transform _aimArrow;

    private AimInput _input;

    private float _aim;
    private float _accumulatedForce;
    private object _timerId = new object();

    private Vector3 _originalDebugCookiePos;
    private Transform _originalCookieParentDebug;

    private void Awake()
    {
		_aimSlider.fillAmount = 0;
        _input = GetComponent<AimInput>();
        /*_originalCookieParentDebug = _collectObjects.GetCurrentItem?.transform.parent;
		_originalDebugCookiePos = _collectObjects.GetCurrentItem.transform.localPosition;*/
    }

    private void Update()
    {
        AddAim(_input.GetAim() * Time.deltaTime * _aimSpeed);
        if (_input.GetForceButtonDown()) StartApplyingForce();
        if (_input.GetForceButtonUp()) LaunchProjectile();

        _isFacingRight = _shooterController.IsFacingRight;
        var angle = GetAngleForNormalizedInput(_aim, _isFacingRight);
        _aimTransform.localRotation = Quaternion.Euler(0, 0, angle);
		_aimArrow.localRotation = Quaternion.Euler(0, 0, angle);
    }

    public void StartApplyingForce()
    {
        if (!HasObject) return;
        DOTween.Kill(_timerId);
        _accumulatedForce = 0;
		_aimSlider.gameObject.SetActive(true);

        DOVirtual.Float(0, 1f, _maxForceTime, normalizedValue =>
        {
			_aimSlider.fillAmount = normalizedValue;
            _accumulatedForce = (normalizedValue * _maxForce);
            //_aimTransform.localScale = new Vector3(_aimTransform.localScale.x, _accumulatedForce * 0.5f, _aimTransform.localScale.z);
        })
        .OnComplete(LaunchProjectile)
        .SetId(_timerId);
    }

    /*public void ResetCookie()
	{
		var rb = _collectObjects.GetCurrentItem.GetComponent<Rigidbody2D>();
		rb.velocity = Vector2.zero;
		rb.isKinematic = true;
		rb.transform.SetParent(_originalCookieParentDebug, true);
		rb.transform.localPosition = _originalDebugCookiePos;
	}*/

    public void LaunchProjectile()
    {
        if (!HasObject) return;
        DOTween.Kill(_timerId);

		_aimSlider.gameObject.SetActive(false);
        _aimTransform.localScale = new Vector3(_aimTransform.localScale.x, 1 * 0.5f, _aimTransform.localScale.z);
        try
        {
            _collectObjects.GetCurrentItem.GetComponent<Item>().acceleration = _accumulatedForce;
        }
        catch
        {
            Debug.Log("Can not set acc force");
        }
        var spriteRenderer = _collectObjects.GetCurrentItem.GetComponent<Item>().anim.GetComponent<SpriteRenderer>();
        spriteRenderer.sortingOrder = 10;

        var rb = _collectObjects.GetCurrentItem.GetComponent<Rigidbody2D>();
        rb.transform.SetParent(null, true);
        rb.isKinematic = false;
        rb.velocity = Vector2.zero;
        rb.AddForce(_aimTransform.up * (_minForce + _accumulatedForce), ForceMode2D.Impulse);

		SoundManager.Instance.PlayThrow();

        _collectObjects.ReleaseCurrent();
    }

    public void AddAim(float aim)
    {
        _aim = Mathf.Clamp01(_aim + aim * -1 * _aimSpeed);
    }

    private float GetAngleForNormalizedInput(float normalizedAim, bool isFacingRight)
    {
        return normalizedAim * _maxAngle;
    }
}
