﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class ShooterController : MonoBehaviour
{
	[SerializeField]
	private InputBase inputPlayer;

	[SerializeField, Header("Variables")]
	private float speed;
	[SerializeField]
	private float jumpForce;
	[SerializeField]
	private int jumpCount = 2;

	private Rigidbody2D rb;
	private float inputX = 0;
	private bool inGround = false;
	private int currJump = 0;
    private bool doubleJump = false;

	public bool IsFacingRight {get;set;}
    public bool CanStartPlayer { get; set; }
    public Rigidbody2D Rb { get => rb; }
    public bool InGround { get => inGround; }
    public bool DoubleJump { get => doubleJump; }

    private void Awake()
    {
        this.inputPlayer = GetComponent<InputBase>();
        this.rb = GetComponent<Rigidbody2D>();
    }

    void Update()
    {
        if(CanStartPlayer)
        {
            inputX = inputPlayer.GetXInput();

            Jump();
        }
    }

    private void FixedUpdate()
    {
        Move();
    }

    private void Move()
    {
        if (CanStartPlayer)
        {
            if (inputX < -0.01f || inputX > 0.01f)
            {
                IsFacingRight = inputX >= 0;
                rb.velocity = new Vector2((inputX * speed) * Time.fixedDeltaTime, rb.velocity.y);
            }
        }
    }

    private void Jump()
    {
        if(inputPlayer.GetJumpInput())
        {
            if(currJump < jumpCount)
            {
                rb.velocity = new Vector2(rb.velocity.x, 0);
                rb.AddForce(transform.up * jumpForce, ForceMode2D.Impulse);
                currJump++;
                inGround = false;
                if(currJump > 1)
                {
                    doubleJump = true;
                }
            }
        }
    }

    private void OnCollisionEnter2D(Collision2D collision)
    {
        if(collision.gameObject.tag == "Ground")
        {
            inGround = true;
            doubleJump = false;
            currJump = 0;
        }
    }
}
