﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class RestartGame : MonoBehaviour
{
    public static RestartGame Instance = null;

    [SerializeField, Header("PLAYERS")]
    private CollectorMove playerOne;
    [SerializeField]
    private ShooterController playerTwo;
    [SerializeField, Header("START SPAWN POINTS")]
    private Transform startPlayerOne;
    [SerializeField]
    private Transform startPlayerTwo;
    [SerializeField, Header("VARIABLES")]
    private float delayRealoadGame = 1f;
    [SerializeField]
    private float delayStartGame = 1f;
    [SerializeField]
    private float delayEndGame = 1f;

    private void Awake()
    {
        Instance = this;
    }

    public void RestartGamerRutine()
    {
        StartCoroutine(RutineRestart());
    }

    IEnumerator RutineRestart()
    {
        Debug.Log("SHOW SCORE");
        WinText.Instance.OnOffGameRoundOne(true);
        DesactivePlayer();
        yield return new WaitForSecondsRealtime(delayRealoadGame);
        StartGame();

    }

    public void StartGame()
    {
        StartCoroutine(RutineStart());
        GameManager.Instance.OnItemSaved(0);
    }

    IEnumerator RutineStart()
    {
        playerOne.transform.position = startPlayerOne.position;
        playerTwo.transform.position = startPlayerTwo.position;
        WinText.Instance.OnOffGameRoundOne(false);
        yield return StartCoroutine(CountDown());

        playerOne.CanStartPlayer = true;
        playerTwo.CanStartPlayer = true;
    }

    IEnumerator CountDown()
    {
        WinText.Instance.OnOffTextInfo(true);
        WinText.Instance.UpdateText("3");
        yield return new WaitForSecondsRealtime(1f);
        WinText.Instance.UpdateText("2");
        yield return new WaitForSecondsRealtime(1f);
        WinText.Instance.UpdateText("1");
        yield return new WaitForSecondsRealtime(1f);
        WinText.Instance.UpdateText("START");
        yield return new WaitForSecondsRealtime(1f);
        WinText.Instance.OnOffTextInfo(false);
    }

    public void EndGameResult()
    {
        StartCoroutine(RutineEndGame());
    }

    IEnumerator RutineEndGame()
    {
        WinText.Instance.OnOffGameRoundTwo(true);
        DesactivePlayer();
        yield return new WaitForSecondsRealtime(delayEndGame);
        ScoreManager.Instance.CalculateWin();
        WinText.Instance.OnOffGameRoundTwo(false);
    }

    void DesactivePlayer()
    {
        playerOne.CanStartPlayer = false;
        playerTwo.CanStartPlayer = false;
        playerOne.Rb.velocity = Vector2.zero;
        playerTwo.Rb.velocity = Vector2.zero;
    }
}
